<?php

namespace Drupal\analytics_logging\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\eck\Entity\EckEntityBundle;
use Drupal\field\FieldConfigInterface;

/**
 * UMP rule created/edit form..
 */
class RestExampleForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'analytics_logging_rest_example_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $eck_entity_type = NULL) {
    $example = <<<'EOD'
$endpoint = '%%ENDPOINT%%/';

// User which is allowed to create the entity.
$username = '%%USERNAME%%';
$password = '%%USERNAME%%';

// Get the token needed for entity creation.
$curl = curl_init();
curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
curl_setopt($curl, CURLOPT_URL, $endpoint . 'rest/session/token');
$token = curl_exec($curl);
curl_close($curl);

// Create the entity.
$curl = curl_init();
curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
curl_setopt($curl, CURLOPT_URL, $endpoint . 'entity/%%ENTITY_BUNDLE_OF%%?_format=hal_json');
curl_setopt($curl, CURLOPT_POST, 1);
$post = [
  'type' => [['target_id' => '%%ENTIY_TYPE%%']],
  '_links' => ['type' => [
    'href' => $endpoint . 'rest/type/%%ENTITY_BUNDLE_OF%%/%%ENTIY_TYPE%%'
  ]],
  %%FIELDS%%
];
$header = array(
  'Content-type: application/hal+json',
  'X-CSRF-Token: ' . $token,
);
curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode($post));
curl_setopt($curl, CURLOPT_HTTPHEADER, $header);
curl_setopt($curl, CURLOPT_USERPWD, $username . ":" . $password);
$resp = curl_exec($curl);
EOD;

    $bundle = EckEntityBundle::load($eck_entity_type);
    $all_fields = \Drupal::service('entity_field.manager')->getFieldDefinitions($bundle->getEntityType()->getBundleOf(), $eck_entity_type);
    $field_text = "";
    foreach ($all_fields as $key => $field) {
      if ($field instanceof FieldConfigInterface) {
        $field_text .= "'" . $key . "' => [['value' => '%%VALUE%%']], ";
      }
    }

    $placeholders = [
      '%%ENDPOINT%%' => \Drupal::request()->getSchemeAndHttpHost(),
      '%%ENTITY_BUNDLE_OF%%' => $bundle->getEntityType()->getBundleOf(),
      '%%ENTIY_TYPE%%' => $eck_entity_type,
      '%%FIELDS%%' => $field_text,
    ];
    foreach ($placeholders as $key => $value) {
      $example = str_replace($key, $value, $example);
    }

    $form['rest_example'] = [
      '#type' => 'textarea',
      '#title' => t('Rest Exampple'),
      '#description' => t('Make sure you replace all the placeholders: %%...%%'),
      '#default_value' => $example,
      '#disabled' => TRUE,
      '#rows' => 20,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

  }

}
