<?php

namespace Drupal\analytics_logging\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\user\Form\UserPermissionsForm;

/**
 * Provides the permissions administration form for a specific ECK entity type.
 *
 * @internal
 */
class UserPermissionsEntityTypeSpecificForm extends UserPermissionsForm {

  /**
   * Builds the permissions administration form for a specific ECK entity type.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   * @param string $eck_entity_type
   *   (optional) The ECK entity type. Defaults to NULL.
   */
  public function buildForm(array $form, FormStateInterface $form_state, string $eck_entity_type = NULL) {

    $parent = parent::buildForm($form, $form_state);
    // We want to keep only the permission below in our list.
    $keep_permissions = [
      'create ' . $eck_entity_type . ' entities',
      'delete any ' . $eck_entity_type . ' entities',
      'delete own ' . $eck_entity_type . ' entities',
      'edit any ' . $eck_entity_type . ' entities',
      'edit own ' . $eck_entity_type . ' entities',
      'view any ' . $eck_entity_type . ' entities',
      'view own ' . $eck_entity_type . ' entities',
    ];
    foreach ($parent['permissions'] as $key => $permission) {
      if (substr($key, 0, 1) != '#' && !in_array($key, $keep_permissions)) {
        unset($parent['permissions'][$key]);
      }
    }
    return $parent;

  }

}
